@@ -1,6 +1,8 @@
 # flake8: noqa
+from .flow import FlowAPI, FlowResults
 from .io import SinkType, SourceType
 from .processor import ProcessorAPI
+from .options import StreamingOptions
 
 # NOTE: Only API code should go into this directory. Any runtime code should go
 # into the runtime directory.
