@@ -27,7 +27,10 @@ class FlowAPI:
 
     def run(
         processor_instance: Optional[ProcessorAPI] = None,
+        *,
         streaming_options: options.StreamingOptions = options.StreamingOptions(
-        )
+        ),
+        disable_usage_stats: bool = False,
+        enable_resource_creation: bool = True,
     ) -> FlowResults:
         pass
