@@ -40,11 +40,9 @@ class SqsIoTest(unittest.TestCase):
     def setUp(self) -> None:
         self.output_path = tempfile.mkdtemp()
         self.flow = buildflow.Flow()
-        os.environ['AWS_DEFAULT_REGION'] = 'us-east-1'
 
     def tearDown(self) -> None:
         shutil.rmtree(self.output_path)
-        del os.environ['AWS_DEFAULT_REGION']
 
     @pytest.fixture(autouse=True)
     def inject_fixtures(self, caplog):
@@ -52,26 +50,28 @@ class SqsIoTest(unittest.TestCase):
 
     @mock_sqs
     def test_sqs_setup_create_queue(self):
-        input_sqs = buildflow.SQSSource(queue_name='queue_name')
+        input_sqs = buildflow.SQSSource(queue_name='queue_name',
+                                        region='us-east-2')
 
         with self._caplog.at_level(logging.WARNING):
             input_sqs.setup()
             self.assertEqual(self._caplog.records[0].message,
                              'Queue does not exist attempting to create')
 
-        client = boto3.client('sqs')
+        client = boto3.client('sqs', region_name='us-east-2')
 
         response = client.get_queue_url(QueueName='queue_name')
 
         self.assertEqual(
             response['QueueUrl'],
-            'https://sqs.us-east-1.amazonaws.com/123456789012/queue_name')
+            'https://sqs.us-east-2.amazonaws.com/123456789012/queue_name')
 
     @mock_sqs
     def test_sqs_setup_queue_exists(self):
-        input_sqs = buildflow.SQSSource(queue_name='queue_name')
+        input_sqs = buildflow.SQSSource(queue_name='queue_name',
+                                        region='us-east-2')
 
-        client = boto3.client('sqs')
+        client = boto3.client('sqs', region_name='us-east-2')
         client.create_queue(QueueName='queue_name')
 
         with self._caplog.at_level(logging.WARNING):
@@ -101,6 +101,7 @@ class SqsIoTest(unittest.TestCase):
         }])
 
         input_sqs = buildflow.SQSSource(queue_name='queue_name',
+                                        region='us-east-2',
                                         _test_sqs_client=fake_sqs)
 
         @self.flow.processor(source=input_sqs,
@@ -142,6 +143,7 @@ class SqsIoTest(unittest.TestCase):
         }])
 
         input_sqs = buildflow.SQSSource(queue_name='queue_name',
+                                        region='us-east-2',
                                         _test_sqs_client=fake_sqs)
 
         @self.flow.processor(source=input_sqs,
