@@ -43,4 +43,4 @@ def process(element: Dict[str, Any]):
 
 
 # Run our flow.
-flow.run()
\ No newline at end of file
+flow.run().output()
\ No newline at end of file
