@@ -17,13 +17,14 @@ from buildflow import Flow
 # Parser to allow run time configuration of arguments
 parser = argparse.ArgumentParser()
 parser.add_argument('--queue_name', type=str, required=True)
+parser.add_argument('--region', type=str, default='us-east-2')
 parser.add_argument('--file_path',
                     type=str,
                     default='/tmp/buildflow/local_pubsub.parquet')
 args, _ = parser.parse_known_args(sys.argv)
 
 
-source = buildflow.SQSSource(queue_name=args.queue_name)
+source = buildflow.SQSSource(queue_name=args.queue_name, region=args.region)
 sink = buildflow.FileSink(file_path=args.file_path,
                           file_format=buildflow.FileFormat.PARQUET)
 
