@@ -21,4 +21,4 @@ class MyProcessor(buildflow.Processor):
         return [payload, payload]
 
 
-flow.run(MyProcessor())
+flow.run(MyProcessor()).output()
